[gnome-online-accounts] imap-smtp: Reuse IMAP username by default



commit e47f11399fd0d228f7926a03eeea07e05d610fb3
Author: Christophe Fergeau <cfergeau redhat com>
Date:   Mon Mar 28 10:46:31 2016 +0200

    imap-smtp: Reuse IMAP username by default
    
    We already automatically reuse the IMAP password on the SMTP page. It
    makes sense to also keep the IMAP username as they are likely to go in
    tandem.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=764283

 src/goabackend/goaimapsmtpprovider.c |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
---
diff --git a/src/goabackend/goaimapsmtpprovider.c b/src/goabackend/goaimapsmtpprovider.c
index a0988b0..01acd39 100644
--- a/src/goabackend/goaimapsmtpprovider.c
+++ b/src/goabackend/goaimapsmtpprovider.c
@@ -1021,7 +1021,8 @@ add_account (GoaProvider    *provider,
 
   /* SMTP */
 
-  /* Re-use the password from the IMAP page */
+  /* Re-use the username and password from the IMAP page */
+  gtk_entry_set_text (GTK_ENTRY (data.smtp_username), imap_username);
   gtk_entry_set_text (GTK_ENTRY (data.smtp_password), imap_password);
 
   gtk_notebook_next_page (GTK_NOTEBOOK (data.notebook));


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]